@@ -29,6 +29,11 @@ class ListCommand(BaseListCommand, Lister):
     """
     log = logging.getLogger(__name__)
 
+    def get_parser(self, prog_name):
+        parser = super(ListCommand, self).get_parser(prog_name=prog_name)
+        parser.add_argument('--tag', dest='tag')
+        return parser
+
     def take_action(self, parsed_args):
         client = get_client(parsed_args)
 
